@@ -267,7 +267,7 @@ class Completion:
                     return document
         except Exception as e:
             logging.error(f"Error in async request: {e}")
-            return {}
+            raise e
 
     def get_completions_for_prompt(self, prompt: str, prompt_version: str = None) -> List[Dict[Any, Any]]:
         """
